import { DetailedHTMLProps, InputHTMLAttributes } from 'react'

type ICheckbox = {
  value?: boolean
  label?: string
} & Omit<DetailedHTMLProps<InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>, 'value'>

const Checkbox = ({ name, label, id, value = false, type, ...props }: ICheckbox) => {
  return (
    <div className='checkbox'>
      <label htmlFor={id || name}>
        {label || name}
        <span className={value ? 'checked' : 'unchecked'} />
      </label>
      <input id={id || name} name={name} checked={value} type='checkbox' {...props} />
      <style jsx>{`
        input {
          display: none;
        }
        label span {
          position: relative;
          display: block;
          width: 1.2em;
          height: 1.2em;
          background: transparent;
          border: 2px solid black;
        }
        label span.checked {
          border: 2px solid green;
        }

        label span::after,
        label span::before {
          display: block;
          content: '';
          position: absolute;
          height: 2px;
          left: 0;
          right: 0;
          top: 50%;
          vertical-align: middle;
          background-color: black;
          transition: all 250ms ease-in-out;
        }
        label span.checked::before,
        label span.checked::after {
          background-color: green;
        }

        label span::before {
          transform: translate(0, -50%) rotate(-45deg) scale(0);
        }
        label span::after {
          transform: translate(0, -50%) rotate(45deg) scale(0);
        }

        label span.checked::before {
          transform: translate(0, -50%) rotate(-45deg) scale(1);
        }
        label span.checked::after {
          transform: translate(0, -50%) rotate(45deg) scale(1);
        }
      `}</style>
    </div>
  )
}

export default Checkbox
