import { useTrainingTypesQuery, TrainingType } from '../../gql'
import AddTrainingType from './AddTrainingType'
import { useState, useEffect } from 'react'
import { Modal } from '../../modal'
import Select from '../../form/components/Select'

interface ITrainingTypeSelector {
  value?: TrainingType
  onChange: GenericEventHandler
  name?: string
  label?: string
  className?: string
}

const TrainingTypeSelector = ({
  value,
  onChange,
  name = 'type',
  label = 'Training type',
  className = 'training-type',
}: ITrainingTypeSelector) => {
  const [modalState, setModalState] = useState(false)
  const trainingTypes = useTrainingTypesQuery()
  const id = value?.id ?? ''

  useEffect(() => {
    if (trainingTypes.data && trainingTypes.data.trainingTypes.length > 0 && !id) {
      onChange({
        target: {
          type: 'custom',
          value: trainingTypes.data.trainingTypes[0],
          name,
        },
      })
    }
  }, [trainingTypes.data])

  return (
    <div className={className}>
      <label>{label}</label>
      <select id={name} name={name} value={id} onChange={onChange}>
        {trainingTypes.loading && 'loading training types...'}
        {trainingTypes.error && 'error loading training types'}
        {trainingTypes.data &&
          trainingTypes.data.trainingTypes.map((trainingType) => (
            <option key={trainingType.id} value={trainingType.id}>
              {trainingType.name}
            </option>
          ))}
      </select>
      <button
        type='button'
        onClick={(event) => {
          setModalState(true)
        }}
      >
        Add type
      </button>
      <Modal state={[modalState, setModalState]}>
        <AddTrainingType
          onSuccess={(result) => {
            setModalState(false)
            if (result.data) {
              onChange({
                target: {
                  type: 'custom',
                  value: { id: result.data.createTrainingType.id },
                  name,
                },
              })
            }
          }}
        />
      </Modal>

      <style jsx>{`
        label,
        select,
        button {
          display: inline-block;
          width: auto;
        }
      `}</style>
    </div>
  )
}
export default TrainingTypeSelector
